Django Application Package Skeleton

The following features exists

-   Testing package with ``setup.py``
-   Special django package test tools
-   Automatically follow the version number with ``git tag -a``
    command and ``git commit``
